@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  *  The Contents of this file are made available subject to the terms of
@@ -86,7 +87,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
             m_xFilterList.setPropertyValue( "Dropdown", Boolean.TRUE );
             m_xFilterList.setPropertyValue( "LineCount", Short.valueOf( (short)11 ) );
             m_xFilterList.setPropertyValue( "StringItemList", new String[] { "ever (means no filter)", "this morning", "1 week ago", "1 month ago", "1 year ago", "<other>" } );
-            m_xFilterList.setPropertyValue( "DefaultSelection", new Short[] { Short.valueOf( (short)0 ) } );
+            m_xFilterList.setPropertyValue( "DefaultSelection", new short[] { (short)0 } );
 
             m_xApplyFilter.setPropertyValue( "Label", "Apply Filter" );
 
@@ -383,7 +384,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
 
         if ( aFilterItems.size() > 10 ) // (6 standard items + 5 user defined items)
         {
-            // the first (and thus oldes) user defined item
+            // the first (and thus oldest) user defined item
             aFilterItems.remove( 6 );
             // keep our date vector synchron
             m_aFilterDates.remove( 6 );
@@ -455,7 +456,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     public boolean approveReset( EventObject aEvent ) throws com.sun.star.uno.RuntimeException
     {
         return false;
-            // do not allow the date field to be reset - it would set it's content
+            // do not allow the date field to be reset - it would set its content
             // to the current date
             // Note that another possible solution would be to wait for the resetted
             // event and correct the value there
@@ -505,3 +506,5 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
