@@ -1,29 +1,17 @@
 var searchData=
 [
-  ['partialweakcomponentimplhelper1',['PartialWeakComponentImplHelper1',['../a01057.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper1',['PartialWeakComponentImplHelper1',['../a01057.html#ad97918a5f807f99bdc14421edeebd2f2',1,'cppu::PartialWeakComponentImplHelper1']]],
-  ['partialweakcomponentimplhelper10',['PartialWeakComponentImplHelper10',['../a01081.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper10',['PartialWeakComponentImplHelper10',['../a01081.html#a4aa8ac6b4f8cd9e30f89dc04cbf55d66',1,'cppu::PartialWeakComponentImplHelper10']]],
-  ['partialweakcomponentimplhelper11',['PartialWeakComponentImplHelper11',['../a01105.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper11',['PartialWeakComponentImplHelper11',['../a01105.html#a8bc992f2810f9b6d83a64c514ce83aae',1,'cppu::PartialWeakComponentImplHelper11']]],
-  ['partialweakcomponentimplhelper12',['PartialWeakComponentImplHelper12',['../a01129.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper12',['PartialWeakComponentImplHelper12',['../a01129.html#ab3b95cac0fe5185140aea15a59c45d9d',1,'cppu::PartialWeakComponentImplHelper12']]],
-  ['partialweakcomponentimplhelper2',['PartialWeakComponentImplHelper2',['../a01153.html#aaf86478a9edc507fac386f7719832d82',1,'cppu::PartialWeakComponentImplHelper2']]],
-  ['partialweakcomponentimplhelper2',['PartialWeakComponentImplHelper2',['../a01153.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper3',['PartialWeakComponentImplHelper3',['../a01177.html#a1fae15686ed3f50c13be749e41abfdc4',1,'cppu::PartialWeakComponentImplHelper3']]],
-  ['partialweakcomponentimplhelper3',['PartialWeakComponentImplHelper3',['../a01177.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper4',['PartialWeakComponentImplHelper4',['../a01201.html#a926935842b1eb7770d5d424e70d15b7a',1,'cppu::PartialWeakComponentImplHelper4']]],
-  ['partialweakcomponentimplhelper4',['PartialWeakComponentImplHelper4',['../a01201.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper5',['PartialWeakComponentImplHelper5',['../a01225.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper5',['PartialWeakComponentImplHelper5',['../a01225.html#af4ea5bcbb7abfd953f87ec664f2b1622',1,'cppu::PartialWeakComponentImplHelper5']]],
-  ['partialweakcomponentimplhelper6',['PartialWeakComponentImplHelper6',['../a01249.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper6',['PartialWeakComponentImplHelper6',['../a01249.html#accf10e5033415e7172000026c403f07f',1,'cppu::PartialWeakComponentImplHelper6']]],
-  ['partialweakcomponentimplhelper7',['PartialWeakComponentImplHelper7',['../a01273.html#afdd0624147f4ba45945d8efe62a033bd',1,'cppu::PartialWeakComponentImplHelper7']]],
-  ['partialweakcomponentimplhelper7',['PartialWeakComponentImplHelper7',['../a01273.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper8',['PartialWeakComponentImplHelper8',['../a01297.html#a47b70ed7d7dda1c0086dc8257756265b',1,'cppu::PartialWeakComponentImplHelper8']]],
-  ['partialweakcomponentimplhelper8',['PartialWeakComponentImplHelper8',['../a01297.html',1,'cppu']]],
-  ['partialweakcomponentimplhelper9',['PartialWeakComponentImplHelper9',['../a01321.html#a6e35384941caa029cf3963ecb72374bf',1,'cppu::PartialWeakComponentImplHelper9']]],
-  ['partialweakcomponentimplhelper9',['PartialWeakComponentImplHelper9',['../a01321.html',1,'cppu']]],
+  ['partialweakcomponentimplhelper1',['PartialWeakComponentImplHelper1',['../a01057.html',1,'cppu::PartialWeakComponentImplHelper1&lt; Ifc1 &gt;'],['../a01057.html#ad97918a5f807f99bdc14421edeebd2f2',1,'cppu::PartialWeakComponentImplHelper1::PartialWeakComponentImplHelper1()']]],
+  ['partialweakcomponentimplhelper10',['PartialWeakComponentImplHelper10',['../a01081.html',1,'cppu::PartialWeakComponentImplHelper10&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10 &gt;'],['../a01081.html#a4aa8ac6b4f8cd9e30f89dc04cbf55d66',1,'cppu::PartialWeakComponentImplHelper10::PartialWeakComponentImplHelper10()']]],
+  ['partialweakcomponentimplhelper11',['PartialWeakComponentImplHelper11',['../a01105.html',1,'cppu::PartialWeakComponentImplHelper11&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11 &gt;'],['../a01105.html#a8bc992f2810f9b6d83a64c514ce83aae',1,'cppu::PartialWeakComponentImplHelper11::PartialWeakComponentImplHelper11()']]],
+  ['partialweakcomponentimplhelper12',['PartialWeakComponentImplHelper12',['../a01129.html',1,'cppu::PartialWeakComponentImplHelper12&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12 &gt;'],['../a01129.html#ab3b95cac0fe5185140aea15a59c45d9d',1,'cppu::PartialWeakComponentImplHelper12::PartialWeakComponentImplHelper12()']]],
+  ['partialweakcomponentimplhelper2',['PartialWeakComponentImplHelper2',['../a01153.html',1,'cppu::PartialWeakComponentImplHelper2&lt; Ifc1, Ifc2 &gt;'],['../a01153.html#aaf86478a9edc507fac386f7719832d82',1,'cppu::PartialWeakComponentImplHelper2::PartialWeakComponentImplHelper2()']]],
+  ['partialweakcomponentimplhelper3',['PartialWeakComponentImplHelper3',['../a01177.html',1,'cppu::PartialWeakComponentImplHelper3&lt; Ifc1, Ifc2, Ifc3 &gt;'],['../a01177.html#a1fae15686ed3f50c13be749e41abfdc4',1,'cppu::PartialWeakComponentImplHelper3::PartialWeakComponentImplHelper3()']]],
+  ['partialweakcomponentimplhelper4',['PartialWeakComponentImplHelper4',['../a01201.html',1,'cppu::PartialWeakComponentImplHelper4&lt; Ifc1, Ifc2, Ifc3, Ifc4 &gt;'],['../a01201.html#a926935842b1eb7770d5d424e70d15b7a',1,'cppu::PartialWeakComponentImplHelper4::PartialWeakComponentImplHelper4()']]],
+  ['partialweakcomponentimplhelper5',['PartialWeakComponentImplHelper5',['../a01225.html',1,'cppu::PartialWeakComponentImplHelper5&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5 &gt;'],['../a01225.html#af4ea5bcbb7abfd953f87ec664f2b1622',1,'cppu::PartialWeakComponentImplHelper5::PartialWeakComponentImplHelper5()']]],
+  ['partialweakcomponentimplhelper6',['PartialWeakComponentImplHelper6',['../a01249.html',1,'cppu::PartialWeakComponentImplHelper6&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6 &gt;'],['../a01249.html#accf10e5033415e7172000026c403f07f',1,'cppu::PartialWeakComponentImplHelper6::PartialWeakComponentImplHelper6()']]],
+  ['partialweakcomponentimplhelper7',['PartialWeakComponentImplHelper7',['../a01273.html',1,'cppu::PartialWeakComponentImplHelper7&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7 &gt;'],['../a01273.html#afdd0624147f4ba45945d8efe62a033bd',1,'cppu::PartialWeakComponentImplHelper7::PartialWeakComponentImplHelper7()']]],
+  ['partialweakcomponentimplhelper8',['PartialWeakComponentImplHelper8',['../a01297.html',1,'cppu::PartialWeakComponentImplHelper8&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8 &gt;'],['../a01297.html#a47b70ed7d7dda1c0086dc8257756265b',1,'cppu::PartialWeakComponentImplHelper8::PartialWeakComponentImplHelper8()']]],
+  ['partialweakcomponentimplhelper9',['PartialWeakComponentImplHelper9',['../a01321.html',1,'cppu::PartialWeakComponentImplHelper9&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9 &gt;'],['../a01321.html#a6e35384941caa029cf3963ecb72374bf',1,'cppu::PartialWeakComponentImplHelper9::PartialWeakComponentImplHelper9()']]],
   ['pasinterface',['pAsInterface',['../a01869.html#a4a5b6002eece0443be0ad7d71e577f80',1,'cppu::detail::element_alias']]],
   ['passequence',['pAsSequence',['../a01869.html#a2849feb18d4685607c4190ff8b9a317d',1,'cppu::detail::element_alias']]],
   ['pattributetyperef',['pAttributeTypeRef',['../a00945.html#a20a170d5cd6cdf145d386ee6d5e328de',1,'_typelib_InterfaceAttributeTypeDescription']]],
@@ -36,8 +24,7 @@ var searchData=
   ['penumvalues',['pEnumValues',['../a00929.html#a4119dcbcf062d4a8f5ebdbcd3bc4d10f',1,'_typelib_EnumTypeDescription']]],
   ['pextenv',['pExtEnv',['../a00989.html#adb88aa784c41787a519e9a7e03328746',1,'_uno_Environment']]],
   ['pinterface',['pInterface',['../a00941.html#ac7850a4e77e987719a4ffdb674c7c073',1,'_typelib_InterfaceMethodTypeDescription::pInterface()'],['../a00945.html#af1321084a3600eff6785402e592bc206',1,'_typelib_InterfaceAttributeTypeDescription::pInterface()']]],
-  ['pipe',['Pipe',['../a00845.html',1,'osl']]],
-  ['pipe',['Pipe',['../a00845.html#a17018496d18330b47bf15ae243bc1ad6',1,'osl::Pipe::Pipe()'],['../a00845.html#a7a11c06caf238c296b64ffd739b41e0f',1,'osl::Pipe::Pipe(const ::rtl::OUString &amp;strName, oslPipeOptions Options)'],['../a00845.html#ad9c8a93b413e8dca04981d2b15b0f735',1,'osl::Pipe::Pipe(const ::rtl::OUString &amp;strName, oslPipeOptions Options, const Security &amp;rSecurity)'],['../a00845.html#a13242b3691ac95139475e73eddd1fabf',1,'osl::Pipe::Pipe(const Pipe &amp;pipe)'],['../a00845.html#a244cfe606221222f5e1956758102061d',1,'osl::Pipe::Pipe(oslPipe pipe, __sal_NoAcquire noacquire)'],['../a00845.html#a6b4ea3ef48365a495600ac0df2aa81fd',1,'osl::Pipe::Pipe(oslPipe Pipe)']]],
+  ['pipe',['Pipe',['../a00845.html',1,'osl::Pipe'],['../a00845.html#a17018496d18330b47bf15ae243bc1ad6',1,'osl::Pipe::Pipe()'],['../a00845.html#a7a11c06caf238c296b64ffd739b41e0f',1,'osl::Pipe::Pipe(const ::rtl::OUString &amp;strName, oslPipeOptions Options)'],['../a00845.html#ad9c8a93b413e8dca04981d2b15b0f735',1,'osl::Pipe::Pipe(const ::rtl::OUString &amp;strName, oslPipeOptions Options, const Security &amp;rSecurity)'],['../a00845.html#a13242b3691ac95139475e73eddd1fabf',1,'osl::Pipe::Pipe(const Pipe &amp;pipe)'],['../a00845.html#a244cfe606221222f5e1956758102061d',1,'osl::Pipe::Pipe(oslPipe pipe, __sal_NoAcquire noacquire)'],['../a00845.html#a6b4ea3ef48365a495600ac0df2aa81fd',1,'osl::Pipe::Pipe(oslPipe Pipe)']]],
   ['pipe_2eh',['pipe.h',['../a00209.html',1,'']]],
   ['pipe_2ehxx',['pipe.hxx',['../a00212.html',1,'']]],
   ['pipe_5fdecl_2ehxx',['pipe_decl.hxx',['../a00215.html',1,'']]],
@@ -65,10 +52,8 @@ var searchData=
   ['presett',['pResetT',['../a00841.html#a2e8fcd15f092b0edf6631a3ef6eaca2a',1,'osl::ResettableGuard']]],
   ['preturntyperef',['pReturnTypeRef',['../a00941.html#a9594a819a42a5c4396c5461db9ecf92e',1,'_typelib_InterfaceMethodTypeDescription']]],
   ['probefun',['ProbeFun',['../a00537.html#a23dc7962928408b804198f8d5a4c3637',1,'cppu::helper::purpenv']]],
-  ['process_2eh',['process.h',['../a02515.html',1,'']]],
-  ['process_2eh',['process.h',['../a02518.html',1,'']]],
-  ['profile',['Profile',['../a00857.html#adf8dc49d779de9d2cf65f8fd9ce5bc72',1,'osl::Profile']]],
-  ['profile',['Profile',['../a00857.html',1,'osl']]],
+  ['process_2eh',['process.h',['../a02515.html',1,'(Global Namespace)'],['../a02518.html',1,'(Global Namespace)']]],
+  ['profile',['Profile',['../a00857.html',1,'osl::Profile'],['../a00857.html#adf8dc49d779de9d2cf65f8fd9ce5bc72',1,'osl::Profile::Profile()']]],
   ['profile_2eh',['profile.h',['../a00218.html',1,'']]],
   ['profile_2ehxx',['profile.hxx',['../a00221.html',1,'']]],
   ['profile_5fdefault',['Profile_DEFAULT',['../a00532.html#a74a886f4a072ee5d863466a145ad3c3b',1,'osl']]],
@@ -76,11 +61,9 @@ var searchData=
   ['profile_5fsystem',['Profile_SYSTEM',['../a00532.html#a9bc69bb1ed2a485b6327fc63e2495ccc',1,'osl']]],
   ['profile_5fwritelock',['Profile_WRITELOCK',['../a00532.html#aacff0b381916cd4cf3e416e8ab163d06',1,'osl']]],
   ['profileoption',['ProfileOption',['../a00532.html#a3536004d459516c7dc211063da2cdd86',1,'osl']]],
-  ['propertysetmixin',['PropertySetMixin',['../a01905.html#a80a728283b4e654bb269709412642b4f',1,'cppu::PropertySetMixinImpl::PropertySetMixin()'],['../a01901.html#ab25e1b18e0d90bad12e6592b0b4083db',1,'cppu::PropertySetMixin::PropertySetMixin()']]],
-  ['propertysetmixin',['PropertySetMixin',['../a01901.html',1,'cppu']]],
+  ['propertysetmixin',['PropertySetMixin',['../a01901.html',1,'cppu::PropertySetMixin&lt; T &gt;'],['../a01905.html#a80a728283b4e654bb269709412642b4f',1,'cppu::PropertySetMixinImpl::PropertySetMixin()'],['../a01901.html#ab25e1b18e0d90bad12e6592b0b4083db',1,'cppu::PropertySetMixin::PropertySetMixin()']]],
   ['propertysetmixin_2ehxx',['propertysetmixin.hxx',['../a00455.html',1,'']]],
-  ['propertysetmixinimpl',['PropertySetMixinImpl',['../a01905.html',1,'cppu']]],
-  ['propertysetmixinimpl',['PropertySetMixinImpl',['../a01909.html#ad1e77bcaea8c92ee4fee7d14bcc17431',1,'cppu::PropertySetMixinImpl::BoundListeners']]],
+  ['propertysetmixinimpl',['PropertySetMixinImpl',['../a01905.html',1,'cppu::PropertySetMixinImpl'],['../a01909.html#ad1e77bcaea8c92ee4fee7d14bcc17431',1,'cppu::PropertySetMixinImpl::BoundListeners::PropertySetMixinImpl()']]],
   ['propshlp_2ehxx',['propshlp.hxx',['../a00458.html',1,'']]],
   ['proptypehlp_2eh',['proptypehlp.h',['../a00461.html',1,'']]],
   ['proptypehlp_2ehxx',['proptypehlp.hxx',['../a00464.html',1,'']]],
