@@ -39,12 +39,14 @@ var searchData=
   ['scrollbar_2eidl',['ScrollBar.idl',['../ScrollBar_8idl.html',1,'']]],
   ['scrollbarorientation_2eidl',['ScrollBarOrientation.idl',['../ScrollBarOrientation_8idl.html',1,'']]],
   ['searchalgorithms_2eidl',['SearchAlgorithms.idl',['../SearchAlgorithms_8idl.html',1,'']]],
+  ['searchalgorithms2_2eidl',['SearchAlgorithms2.idl',['../SearchAlgorithms2_8idl.html',1,'']]],
   ['searchcommandargument_2eidl',['SearchCommandArgument.idl',['../SearchCommandArgument_8idl.html',1,'']]],
   ['searchcriterium_2eidl',['SearchCriterium.idl',['../SearchCriterium_8idl.html',1,'']]],
   ['searchdescriptor_2eidl',['SearchDescriptor.idl',['../SearchDescriptor_8idl.html',1,'']]],
   ['searchflags_2eidl',['SearchFlags.idl',['../SearchFlags_8idl.html',1,'']]],
   ['searchinfo_2eidl',['SearchInfo.idl',['../SearchInfo_8idl.html',1,'']]],
   ['searchoptions_2eidl',['SearchOptions.idl',['../SearchOptions_8idl.html',1,'']]],
+  ['searchoptions2_2eidl',['SearchOptions2.idl',['../SearchOptions2_8idl.html',1,'']]],
   ['searchrecursion_2eidl',['SearchRecursion.idl',['../SearchRecursion_8idl.html',1,'']]],
   ['searchresult_2eidl',['SearchResult.idl',['../SearchResult_8idl.html',1,'']]],
   ['section_2eidl',['Section.idl',['../Section_8idl.html',1,'']]],
@@ -71,11 +73,9 @@ var searchData=
   ['sessionmanager_2eidl',['SessionManager.idl',['../SessionManager_8idl.html',1,'']]],
   ['setaccess_2eidl',['SetAccess.idl',['../SetAccess_8idl.html',1,'']]],
   ['setelement_2eidl',['SetElement.idl',['../SetElement_8idl.html',1,'']]],
-  ['setexpression_2eidl',['SetExpression.idl',['../fieldmaster_2SetExpression_8idl.html',1,'']]],
-  ['setexpression_2eidl',['SetExpression.idl',['../textfield_2SetExpression_8idl.html',1,'']]],
+  ['setexpression_2eidl',['SetExpression.idl',['../fieldmaster_2SetExpression_8idl.html',1,'(Global Namespace)'],['../textfield_2SetExpression_8idl.html',1,'(Global Namespace)']]],
   ['setpropertytolerantfailed_2eidl',['SetPropertyTolerantFailed.idl',['../SetPropertyTolerantFailed_8idl.html',1,'']]],
-  ['settings_2eidl',['Settings.idl',['../frame_2Settings_8idl.html',1,'']]],
-  ['settings_2eidl',['Settings.idl',['../document_2Settings_8idl.html',1,'']]],
+  ['settings_2eidl',['Settings.idl',['../document_2Settings_8idl.html',1,'(Global Namespace)'],['../frame_2Settings_8idl.html',1,'(Global Namespace)']]],
   ['setupdate_2eidl',['SetUpdate.idl',['../SetUpdate_8idl.html',1,'']]],
   ['setvariabletype_2eidl',['SetVariableType.idl',['../SetVariableType_8idl.html',1,'']]],
   ['shademode_2eidl',['ShadeMode.idl',['../ShadeMode_8idl.html',1,'']]],
@@ -83,11 +83,7 @@ var searchData=
   ['shadowformat_2eidl',['ShadowFormat.idl',['../ShadowFormat_8idl.html',1,'']]],
   ['shadowlocation_2eidl',['ShadowLocation.idl',['../ShadowLocation_8idl.html',1,'']]],
   ['shadowproperties_2eidl',['ShadowProperties.idl',['../ShadowProperties_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../drawing_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../presentation_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../report_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../sheet_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../text_2Shape_8idl.html',1,'']]],
+  ['shape_2eidl',['Shape.idl',['../drawing_2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2Shape_8idl.html',1,'(Global Namespace)'],['../report_2Shape_8idl.html',1,'(Global Namespace)'],['../sheet_2Shape_8idl.html',1,'(Global Namespace)'],['../text_2Shape_8idl.html',1,'(Global Namespace)']]],
   ['shapeanimationsubtype_2eidl',['ShapeAnimationSubType.idl',['../ShapeAnimationSubType_8idl.html',1,'']]],
   ['shapecollection_2eidl',['ShapeCollection.idl',['../ShapeCollection_8idl.html',1,'']]],
   ['shapes_2eidl',['Shapes.idl',['../Shapes_8idl.html',1,'']]],
@@ -178,9 +174,7 @@ var searchData=
   ['standarddiagramcreationparameters_2eidl',['StandardDiagramCreationParameters.idl',['../StandardDiagramCreationParameters_8idl.html',1,'']]],
   ['startmodule_2eidl',['StartModule.idl',['../StartModule_8idl.html',1,'']]],
   ['statechangeinprogressexception_2eidl',['StateChangeInProgressException.idl',['../StateChangeInProgressException_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../sdbcx_2Statement_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../sdbc_2Statement_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../rdf_2Statement_8idl.html',1,'']]],
+  ['statement_2eidl',['Statement.idl',['../rdf_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbc_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Statement_8idl.html',1,'(Global Namespace)']]],
   ['statusbarcontroller_2eidl',['StatusbarController.idl',['../StatusbarController_8idl.html',1,'']]],
   ['statusbarcontrollerfactory_2eidl',['StatusbarControllerFactory.idl',['../StatusbarControllerFactory_8idl.html',1,'']]],
   ['statusbarfunction_2eidl',['StatusBarFunction.idl',['../StatusBarFunction_8idl.html',1,'']]],
@@ -201,15 +195,13 @@ var searchData=
   ['stringresourcewithlocation_2eidl',['StringResourceWithLocation.idl',['../StringResourceWithLocation_8idl.html',1,'']]],
   ['stringresourcewithstorage_2eidl',['StringResourceWithStorage.idl',['../StringResourceWithStorage_8idl.html',1,'']]],
   ['strokeattributes_2eidl',['StrokeAttributes.idl',['../StrokeAttributes_8idl.html',1,'']]],
-  ['style_2eidl',['Style.idl',['../style_2Style_8idl.html',1,'']]],
-  ['style_2eidl',['Style.idl',['../awt_2Style_8idl.html',1,'']]],
+  ['style_2eidl',['Style.idl',['../awt_2Style_8idl.html',1,'(Global Namespace)'],['../style_2Style_8idl.html',1,'(Global Namespace)']]],
   ['stylefamilies_2eidl',['StyleFamilies.idl',['../StyleFamilies_8idl.html',1,'']]],
   ['stylefamily_2eidl',['StyleFamily.idl',['../StyleFamily_8idl.html',1,'']]],
   ['subincrement_2eidl',['SubIncrement.idl',['../SubIncrement_8idl.html',1,'']]],
   ['subject_2eidl',['Subject.idl',['../Subject_8idl.html',1,'']]],
   ['submissionpropertyhandler_2eidl',['SubmissionPropertyHandler.idl',['../SubmissionPropertyHandler_8idl.html',1,'']]],
-  ['submitbutton_2eidl',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'']]],
-  ['submitbutton_2eidl',['SubmitButton.idl',['../control_2SubmitButton_8idl.html',1,'']]],
+  ['submitbutton_2eidl',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../control_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
   ['subtitleshape_2eidl',['SubtitleShape.idl',['../SubtitleShape_8idl.html',1,'']]],
   ['subtotalcolumn_2eidl',['SubTotalColumn.idl',['../SubTotalColumn_8idl.html',1,'']]],
   ['subtotaldescriptor_2eidl',['SubTotalDescriptor.idl',['../SubTotalDescriptor_8idl.html',1,'']]],
